@@ -30,7 +30,7 @@ def init (cfg):
   config = cfg
   ldir = config ['log']
   if not os.path.isdir(ldir):
-    os.mkdir (ldir)
+    os.makedirs (ldir)
   fname = os.path.join(ldir, 'errors.yaml')
   if os.path.exists(fname):
     os.remove(fname)
