@@ -42,7 +42,13 @@ def init (cfg):
   '''
   global config
   config = cfg
+  
   dbpath = cfg ['path']
+  dbdir = os.path.dirname(dbpath)
+  
+  if not os.path.exists(dbdir):
+      os.makedirs(dbdir)
+  
   # Open database connection
   db = sqlite3.connect(dbpath)
   print "Opened database successfully";
